#
# spec file for package flameshot
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           flameshot
Version:        0.6.0
Release:        lp151.1.1
Summary:        Screenshot software
License:        GPL-3.0-only
Group:          Productivity/Graphics/Other
URL:            https://github.com/lupoDharkael/flameshot#flameshot
Source0:        https://github.com/lupoDharkael/flameshot/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch1:         desktop-files.patch
Patch2:         0001-utils-confighandler.cpp-Enable-Pin-and-Text-tool-by-.patch
%if 0%{?suse_version} >= 1500
BuildRequires:  gcc-c++
%else
BuildRequires:  gcc7
BuildRequires:  gcc7-c++
%endif
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-qtbase
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Core) >= 5
BuildRequires:  pkgconfig(Qt5DBus) >= 5
BuildRequires:  pkgconfig(Qt5Gui) >= 5
BuildRequires:  pkgconfig(Qt5Network) >= 5
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets) >= 5

%description
A program to capture screenshots.
It includes CLI options as well as a UI for capturing and annotating screenshots.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          Productivity/Graphics/Other
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    packageand(flameshot:bash)
BuildArch:      noarch

%description bash-completion
Bash completion script for flameshot's CLI.

%prep
%autosetup -p1

%if 0%{?suse_version} < 1500
sed -i '/appdata.path/s/metainfo/appdata/' flameshot.pro
%endif

%build
%qmake5 \
%if 0%{?suse_version} < 1500
 QMAKE_CC=gcc-7 QMAKE_CXX=g++-7 \
%endif
 CONFIG+=packaging
%make_jobs

%install
%qmake5_install

%files
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/dbus-1/services/org.dharkael.Flameshot.service
%{_datadir}/dbus-1/interfaces/org.dharkael.Flameshot.xml
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%if 0%{?suse_version} >= 1500
%{_datadir}/metainfo/%{name}.appdata.xml
%else
%{_datadir}/appdata/%{name}.appdata.xml
%endif

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%changelog
* Sun Apr  7 2019 Martin Hauke <mardnh@gmx.de>
- Add patch:
  * 0001-utils-confighandler.cpp-Enable-Pin-and-Text-tool-by-.patch
    Enables Pin and Text tool by default.
* Tue Aug 28 2018 aloisio@gmx.com
- Update to version 0.6.0
  Features:
  * Allow systray customization with themes. Use
    "flameshot-tray" as the name of the icon.
  * Unification of the desktop file with actions.
  * Notification when screenshots are saved in the clipboard.
  * Use datetime as default name for pics.
  * Undo/Redo with Ctrl+z and Ctrl+Shift+z.
  * Add "Take Screenshot" option as menu item in the systray.
  * Add Side-Panel (open it with Space).
  * Add autostart to config flags.
  * Add Pin tool.
  * Filename: replace colons with dashes.
  * Add Text tool.
  * Delete Imgur image button after uploading it from the
    preview window.
  * Capture single screen:
    + flameshot screen (capture the screen containing the mouse)
    + flameshot screen -n 1 (capture the first screen).
  * Store settings colors in hexadecimal format.
  Fixes:
  * flameshot full -c shouldn't block the desktop.
  * Now you can overwrite exported configuration with the same
    name as a previous exports.
  * Fix flameshot --raw wait time with delay.
  * Fix negative selection geometry bug.
  * Improved hidpi support with some bugs fixed.
- Refreshed desktop-files.patch
* Sat Feb 24 2018 avindra@opensuse.org
- Bump to 0.5.1
  * Modal widgets doesn't prevent the start of a new capture
  * Better hidpi support
  * Tool buttons now don't go out of the screen
  * Use of native file dialog
  * Configurable opacity of the dark area outside the selection
  * Autostart app as a configuration option
  * Polish, french, georgian, chinese, turkish and rusian
    translations
  * Minor fixes
- rebase desktop-files.patch
* Thu Dec 28 2017 jengelh@inai.de
- Remove filler wording from description.
* Fri Dec 22 2017 avindra@opensuse.org
- Bump to 0.5.0
  * Features
  - Blur tool
  - Bash completion
  - Add --raw flag: prints the raw bytes of the png after the capture
  - Catalan translation
  - Preview draw size on mouse pointer after tool selection
  - App Launcher tool: choose an app to open the capture
  - Configuration import, export and reset
  - Experimental Wayland support (Plasma & Gnome)
  - Debian package configuration
  * Accessibility
  - Capture selection resizable from any edge
  * Fixes
  - App version shown properly
  - cli wont break if you prepend gui, full and config arguments
    with a dash
  - Fix rare crash when creating a selection during a graphical
    capture
- Build cleanup:
  * Remove unneeded service file
  * Use Qt macros for building and installing
  * Remove now unneeded .deskop file handling macros
- Package bash completions
* Sun Sep 17 2017 aavindraa@gmail.com
- Bump to 0.4.2 (hotfix release)
- hotfix: persistent configuration wasn't handled correctly for new
  users, failing to set a "initiated" status flag in the
  configuration. That is used to let the program know if a new
  process of Flameshot is the first launch of the program.
* Thu Aug 17 2017 aavindraa@gmail.com
- 0.4.0 release (https://github.com/lupoDharkael/flameshot/releases/tag/v0.4.0)
- lint .spec file
* Tue Aug 15 2017 aavindraa@gmail.com
- Package for the first time (with v0.3.0)
